<script setup>
import { Head, Link } from '@inertiajs/vue3';

defineProps({
    canLogin: Boolean,
    canRegister: Boolean,
    laravelVersion: String,
    phpVersion: String,
});

</script>

<template>
    <Head title="Welcome" />
    <div class="mx-auto px-0 bg-gray-900">

        <!-- Hero Section -->
        <section class="relative hero-bg text-center py-24 text-white">
            <div class="absolute inset-0 hero-overlay"></div>
            <div class="relative z-10 max-w-3xl mx-auto px-4">
                <h1 class="text-4xl font-bold mb-4">¡Descubre el Mejor Contenido Multimedia en un Solo Lugar!</h1>
                <p class="text-lg mb-8">Accede a series, películas, animes, novelas y doramas de las principales plataformas de streaming.</p>
                <Link :href="route('register')" class="bg-red-600 text-white py-3 px-6 rounded-lg text-xl font-semibold hover:bg-red-700 transition duration-300">Empieza Ahora</Link>
            </div>
        </section>

        <!-- Features Section -->
        <section class="my-16 text-center container text-gray-300">
            <h2 class="text-3xl text-gray-100 font-bold mb-8">¿Qué Ofrecemos?</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <img src="https://www.plex.tv/wp-content/uploads/2023/05/discover-screen-5.png" alt="Acceso a Contenido Variado" class="h-32 rounded-1 mx-auto mb-4">
                    <h3 class="text-xl font-semibold mb-2">Acceso a Contenido Variado</h3>
                    <p>Series, películas, animes, novelas, doramas y más.</p>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <img src="https://www.dongee.com/tutoriales/content/images/2024/04/image-6.png" alt="Plataformas de Contenido" class="h-32 rounded-1 mx-auto mb-4">
                    <h3 class="text-xl font-semibold mb-2">Plataformas de Contenido</h3>
                    <p>Netflix, Paramount, Max, Disney, Vix, Crunchyroll.</p>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <img src="https://i0.wp.com/blog2.roomiapp.com/wp-content/uploads/2021/01/pelis.jpg?fit=1600%2C1067&ssl=1" alt="Interfaz Intuitiva" class="h-32 rounded-1 mx-auto mb-4">
                    <h3 class="text-xl font-semibold mb-2">Interfaz Intuitiva</h3>
                    <p>Fácil de usar, diseño atractivo.</p>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <img src="https://www.plex.tv/wp-content/uploads/2023/05/movies-and-shows-bg-image-4-1024x555.png" alt="Actualizaciones Regulares" class="h-32 rounded-1 mx-auto mb-4">
                    <h3 class="text-xl font-semibold mb-2">Actualizaciones Regulares</h3>
                    <p>Nuevos contenidos añadidos frecuentemente.</p>
                </div>
            </div>
        </section>

        <!-- How It Works Section -->
        <section class="my-16 text-white text-center">
            <h2 class="text-3xl font-bold text-gray-100 mb-8">Cómo Empezar</h2>
            <div class="flex flex-col md:flex-row justify-center gap-8">
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <span class="fa fa-user-circle text-7xl mb-4"></span>
                    <h3 class="text-xl font-semibold mb-2">Registro</h3>
                    <p>Crea una cuenta en nuestra plataforma.</p>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <span class="fa fa-envelope text-7xl mb-4"></span>
                    <h3 class="text-xl font-semibold mb-2">Verificación de Correo</h3>
                    <p>Confirma tu correo electrónico para acceder al contenido.</p>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg">
                    <span class="fa fa-download text-7xl mb-4"></span>
                    <h3 class="text-xl font-semibold mb-2">Explora y Disfruta</h3>
                    <p>Explora nuestro catálogo y comienza a disfrutar.</p>
                </div>
            </div>
        </section>

        <!-- Pricing Section -->
        <section class="my-16 text-gray-300 text-center container">
            <h2 class="text-3xl font-bold mb-8 text-gray-100">Planes y Precios</h2>
            <div class="flex flex-col md:flex-row justify-center gap-8">
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg w-full md:w-1/3">
                    <h3 class="text-2xl font-bold mb-2">1 MES</h3>
                    <p class="text-xl mb-4">$10</p>
                    <ul class="list-disc list-inside mb-4">
                        <li>Acceso a contenido básico</li>
                        <li>Actualizaciones mensuales</li>
                    </ul>
                    <a target="_blank" href="https://www.gdadictos.com/tienda/?add-to-cart=454" class="bg-red-600 text-white py-3 px-6 rounded-lg text-lg font-semibold hover:bg-red-700 transition duration-300">Elegir Plan</a>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg w-full md:w-1/3">
                    <h3 class="text-2xl font-bold mb-2">3 MESES</h3>
                    <p class="text-xl mb-4">$27</p>
                    <ul class="list-disc list-inside mb-4">
                        <li>Acceso completo a todo el contenido</li>
                        <li>Actualizaciones semanales</li>
                    </ul>
                    <a target="_blank" href="https://www.gdadictos.com/tienda/?add-to-cart=455" class="bg-red-600 text-white py-3 px-6 rounded-lg text-lg font-semibold hover:bg-red-700 transition duration-300">Elegir Plan</a>
                </div>
                <div class="bg-gray-800 p-6 rounded-lg shadow-lg w-full md:w-1/3">
                    <h3 class="text-2xl font-bold mb-2">6 MESES</h3>
                    <p class="text-xl mb-4">$60</p>
                    <ul class="list-disc list-inside mb-4">
                        <li>Acceso completo + contenido exclusivo</li>
                        <li>Soporte prioritario</li>
                    </ul>
                    <a href="https://www.gdadictos.com/tienda/?add-to-cart=456" target="_blank" class="bg-red-600 text-white py-3 px-6 rounded-lg text-lg font-semibold hover:bg-red-700 transition duration-300">Elegir Plan</a>
                </div>
            </div>
        </section>

        <!-- Call to Action Section -->
        <section class="relative cta-bg text-center py-16 mb-0" id="cta">
            <div class="absolute inset-0 cta-overlay"></div>
            <div class="relative z-10 max-w-3xl mx-auto px-4">
                <h2 class="text-3xl font-bold mb-8 text-gray-300">¡No Esperes Más!</h2>
                <a :href="route('register')" class="bg-red-600 text-white py-3 px-6 rounded-lg text-xl font-semibold hover:bg-red-700 transition duration-300">Regístrate Ahora</a>
            </div>
        </section>

    </div>
</template>

<style>
body {
    font-family: 'Poppins', sans-serif;
    margin: 0;
    padding: 0;
    overflow-x: hidden;
}

.text-primary {
    color: #E50914;
}

.bg-dark {
    background-color: #141414;
}

.bg-dark-overlay {
    background-color: rgba(0, 0, 0, 0.6);
}

.section {
    min-height: 100vh;
    padding-top: 80px; /* Space for fixed navbar */
    padding-bottom: 80px; /* Space for fixed footer */
}

#navbar, #footer {
    position: fixed;
    width: 100%;
    z-index: 10;
}

#navbar {
    top: 0;
}

#footer {
    bottom: 0;
}

.content-wrapper {
    margin-top: 80px;
    margin-bottom: 80px;
}
</style>
